#ifndef _CONNECTION_LOG_MODULE_
#define _CONNECTION_LOG_MODULE_

#include <QList>
#include <QRegExp>
#include <QHash>
#include <QDate>
#include <QFileSystemWatcher>

#include "Applet.h"
#include "ui_ConnectionLogModule.h"

class QDir;
class QStringList;
class QRegExp;
class QDialog;
class QAction;


class ConnectionLogModule: public QObject
{
    Q_OBJECT
public:
    struct LogEvent
    {
        QString time;
        QString event;
    };
    struct ConnectionData
    {
        ConnectionData &operator+=( const ConnectionData &other );

        double rx;
        double tx;
    };

    typedef QList<LogEvent> LogEventList; 

    ConnectionLogModule( Applet *parent );
    virtual ~ConnectionLogModule();

    LogEventList getEventsForDate( const QDate &date );
    ConnectionData getDataForDate( const QDate &date );
    ConnectionData getDataForMonth( const QDate &date );

private:
    void refreshLogFiles();

    Applet *applet;
    static const QDir logDir;
    static QRegExp nameRegExp;
    static QRegExp ipRegExp;
    QHash<QString, QDate> logFiles;
    Ui_ConnectionLog ui;
    QDialog m_window;
    QAction *m_menuAction;
    QFileSystemWatcher *m_fsWatcher;

private slots:
    void calendarPageChanged( int year, int month );
    void dateChanged( bool forceSameDate = false );
    void forceUpdate();
    void logDirChanged();
};


extern ConnectionLogModule *connectionLogModule;

#endif
