/*
 * File: DNS_Manager.h
 * Author: Adrian Łubik (2008)
 * License: GNU LGPL v3
 */

#ifndef DNS_MANAGER_H
#define DNS_MANAGER_H

#include <QDebug>
#include <QString>
#include <QStringList>
#include <QFile>
#include <QRegExp>

/**
  * A class for managing DNS servers set in /etc/resolv.conf.
  */
class DNS_Manager
{
public:
    DNS_Manager();
    virtual ~DNS_Manager() {}

    /**
      * Looks up for correct DNS servers.
      * @return QStringList of currently set DNS servers.
      */
    QStringList getDNSServers();

    /**
      * Tries to set the given DNS servers.
      * @return True if the servers has been set.
      */
    bool setServers( QStringList &addresses );

    /**
      * Checks correctness of the /etc/resolv.conf.
      * @return False if no DNS server is set or at
      * least one of set servers is incorrect.
      * Otherwise returns true.
      */
    bool isFileCorrect();

    /**
      * Tries to restore the DNS servers backed up by UbuDSL.
      * @return True if the servers has been restored.
      */
    bool restore();

private:
    QFile *m_resolvConf;
    QFile *m_oldResolvConf;
    QRegExp m_ipRegExp;
    QRegExp m_resolvConfEntry;
};
#endif
