/*
 * File: ModemManager.h
 * Author: Adrian Łubik (2008)
 * License: GNU LGPL v3
 */

#ifndef MODEMMANAGER_H
#define MODEMMANAGER_H

#include <QDBusReply>
#include <QDBusConnection>
#include <QDBusInterface>
#include <QDebug>
#include <QMap>
#include <QList>
#include <QFile>
#include <QSettings>
#include <QString>
#include <QTimer>
#include <QPair>

class ModemManager: public QObject
{
    Q_OBJECT

public:
    struct Modem
    {
        QString name;
        QString driver_name;
        QString driver_version;
        QMultiMap<int, int> usb_id;
    };

    struct ModemDriver
    {
        QString name;
        QString version;
        QString extracted_driver_path;
        QString compiled_driver_name;
        QString extraction_path;
        QString driver_bundle_path;
        QString compilation_arguments;
        QString installation_arguments;
        QString environment_variables;

        bool amd64_compatible;
    };

    ModemManager( const QPair<int, int> &testDeviceID );
    static void initDriversMap( QList<ModemManager::ModemDriver> &driversMap );

    bool    getIsModemFound();
    QString getDriverName();
    QString getDriverVersion();
    QString getModemName();
    QString getUDI();
    int     getVendorID();
    int     getProductID();

public slots:
    void connectToDBus();

private slots:
    void deviceAdded( const QString &udi );
    void verifyDevice();

private:
    void initModemsMap();

    QPair<int, int> m_testDeviceID;

    bool modemFound;
    bool driverInSystem;
    int  n;
    int  vendorID;
    int  productID;

    QList<Modem>  m_modems;
    QString       driverName;
    QString       driverVersion;
    QString       modemName;
    QTimer       *deviceTimer;
    QString       lastAdded;

    Modem sagem_fast_800_e4;
    Modem sagem_fast_800;
    Modem thomson_speedtouch_330;
    Modem zte_zxdsl_852;
    Modem cxacru_based;

signals:
    void message( const QString &msg );
    void foundModem();

};

#endif
