/*
 * File: Rpm.h
 * Author: Adrian Łubik (2008)
 * License: GNU LGPL v3
 */


#ifndef _RPM_H_
#define _RPM_H_

#include <QDebug>
#include <QString>
#include <QStringList>
#include <QList>
#include <QListIterator>
#include <QByteArray>
#include <QProcess>
#include <QThread>

#include "PackageManager.h"

/**
  * A virtual class inherited from the abstract PackageManager class.
  * Implements functions supported by rpm. It's a base for classes
  * that implement RPM-based package managers.
  */
class Rpm: public PackageManager
{
    Q_OBJECT
public:
    Rpm( QThread *parent = 0 );
    virtual ~Rpm();

    virtual QStringList getNotInstalled( QStringList pkgs );
    virtual bool getIsPackageInstalled( const QString &pkg );

    virtual int  installPackages( const QStringList &pkgs ) = 0;
    virtual int  addCD( const QString &mntPoint ) = 0;
    virtual bool getArePackagesAvailable( const QStringList &pkgs ) = 0;

protected:
    int queryDB();
    QList<QByteArray> installedPkgs;
    QByteArray readOutput;
    QProcess *m_askProcess;
};

#endif
