#include "DisconnectThread.h"
#include <QFile>
#include <signal.h>

//extern bool  debug;
//extern FILE *pFile;


DisconnectThread::DisconnectThread( QSettings *settings, QString( *fGetInterface )() )
        : getInterface( fGetInterface ),
        m_settings( settings ),
        m_showMessage( true )
{
    writeLog( "DisconnectThread::DisconnectThread(): called." );
    //nothing to do
    writeLog( "DisconnectThread::DisconnectThread(): finished." );
}

DisconnectThread::~DisconnectThread()
{
    writeLog( "DisconnectThread::~DisconnectThread(): called and finished." );
}

void DisconnectThread::run()
{
    writeLog( "DisconnectThread::run(): called." );
    QString ifaceToKill = getInterface();
    unsigned int pid = 0;

    m_settings->sync();

    if ( m_settings->value( "protocol", "PPPoA" ).toString() == "PPPoE" )
    {
        writeLog( "DisconnectThread::run(): PPPoE connection - killing br2684ctl." );

        if ( readUnsignedFromFile( "/var/run/nas0.pid", pid ) )
        {
            writeLog( QString( "DisconnectThread::run(): kill(%1, 9) (nas0)." ).arg( pid ) );
            int status = kill( pid, 9 );
            writeLog( "DisconnectThread::run(): kill() finished with status: " + QString::number( status ) );
        }
        else
        {
            writeLog( "DisconnectThread::run(): failed to read the brctl2684 pid file!" );
        }

//        writeLog( "DisconnectThread::run(): trying to deprobe the br2684 kernel module." );
//        int exitCode = QProcess::execute( "modprobe -r br2684" );
//        writeLog( "DisconnectThread::run(): be2684 deprobing exit code: " + QString::number( exitCode ) );
    }

    if ( readUnsignedFromFile( "/var/run/ppp-ubudsl.pid", pid ) ||
            readUnsignedFromFile( "/var/run/" + ifaceToKill + ".pid", pid ) )
    {
        writeLog( QString( "DisconnectThread::run(): kill(%1, 15) (pppX)." ).arg( pid ) );
        int status = kill( pid, 15 );
        writeLog( "DisconnectThread::run(): kill() finished with status: " + QString::number( status ) );

        QTimer::singleShot( 1500, this, SLOT( quit() ) );
        exec();

        if ( readUnsignedFromFile( "/var/run/ppp-ubudsl.pid", pid ) ||
                readUnsignedFromFile( "/var/run/" + ifaceToKill + ".pid", pid ) )
        {
            writeLog( "DisconnectThread::run(): pppd is still alive, terminating..." );
            kill( pid, 9 );
        }
        else
        {
            writeLog( "DisconnectThread::run(): pppd is dead - success." );
        }
    }
    else
    {
        writeLog( "DisconnectThread::run(): failed to read the pppd pid file!" );
    }

    removePidFiles( ifaceToKill );

    emit finished( m_showMessage );

    writeLog( "DisconnectThread::run(): finished." );
}

void DisconnectThread::setShowMessage( bool show )
{
    m_showMessage = show;
}

void DisconnectThread::removePidFiles( const QString &killedIface )
{
    QFile::remove( "/var/run/" + killedIface + ".pid" );
    QFile::remove( "/var/run/ppp-ubudsl.pid" );
    QFile::remove( "/var/run/nas0.pid" );
}
